from ..codes import CodeRun


class SiestaRun(CodeRun):

    def __init__(self):
        CodeRun.__init__(self)
        pass

    def set_inputs(self):
        pass

    def get_outputs(self):
        pass

    def is_finished(self):
        pass

    def is_successful(self):
        pass
